@@ -10,7 +10,7 @@ import json, jsons
 import paho.mqtt.client as mqtt
 import psutil
 
-from metrics2mqtt.metrics import CPUMetrics, VirtualMemoryMetrics, DiskUsageMetrics
+from metrics2mqtt.metrics import CPUMetrics, VirtualMemoryMetrics, DiskUsageMetrics, NetworkMetrics
 
 logger = logging.getLogger('metrics2mqtt')
 logger.setLevel(logging.DEBUG)
@@ -70,9 +70,6 @@ class MQTTMetrics(object):
             self.client.publish(metric.topics['config'], json.dumps(config_topic), retain=True, qos=1)
             self._report_status(metric.topics['avail'], True)
 
-    def clean(self):
-        raise NotImplementedError("Clean function doesn't work yet.")
-
     def add_metric(self, metric):
         self.metrics.append(metric)
 
@@ -104,8 +101,6 @@ class MQTTMetrics(object):
                     self._publish_metric(metric)
 def main():
     parser = argparse.ArgumentParser()
-    parser.add_argument("--clean", help="Clean up retained MQTT messages and stuff and exit (NOT IMPLEMENTED YET)", action="store_true")
-    parser.add_argument("--config", help="Create MQTT config topic and exit", action="store_true")
     parser.add_argument('--name', default=socket.gethostname(),
                     help='A descriptive name for the computer being monitored (default: hostname)')
     parser.add_argument('--broker', default="localhost",
@@ -125,7 +120,8 @@ def main():
     parser.add_argument("--vm", help="Publish virtual memory", action="store_true")
     parser.add_argument("--du", help="Publish disk usage metrics", type=str, action="append", 
                         nargs="?", const='/', default=None, metavar='MOUNT')
-
+    parser.add_argument("--net", help="Publish network interface metrics. Specify the interface name and collection interval seperated by a comma", type=str, action="append", 
+                        nargs="?", const='/', default=None, metavar='NIC')
 
     args = parser.parse_args()
     system_name = args.name
@@ -163,16 +159,22 @@ def main():
             du = DiskUsageMetrics(mountpoint=mountpoint)
             stats.add_metric(du)
 
-    if not (args.vm or args.cpu or args.du):
-        logger.warning("No metrics specified. Nothing will be published.")
-    stats.connect()
+    if args.net:
+        for nic in args.net:
+            try:
+                n, i = nic.split(',')
+                i = int(i)
+            except ValueError:
+                n = nic
+                i = 15
+            net = NetworkMetrics(n,i)
+            stats.add_metric(net)
 
-    if args.clean:
-        stats.clean()
-    elif args.config:
-        stats.create_config_topic(exit=True)
-    else:
-        stats.monitor()
+    if not (args.vm or args.cpu or args.du or args.net):
+        logger.warning("No metrics specified. Nothing will be published.")
+
+    stats.connect()
+    stats.monitor()
 
 if __name__ == "__main__":
     main()
\ No newline at end of file
